/* ======================================================================
*   Copyright (C) 2022-2023 Texas Instruments Incorporated
*
*   All rights reserved. Property of Texas Instruments Incorporated.
*   Restricted rights to use, duplicate or disclose this code are
*   granted through contract.
*
*   The program may not be used without the written permission
*   of Texas Instruments Incorporated or against the terms and conditions
*   stipulated in the agreement under which this program has been
*   supplied.
* ==================================================================== */
 /***************************************************************************
  Project: Application_Can
  Date   : 2024-03-23 21:27:51
  This file is generated by EB Tresos
  Do not modify this file, otherwise the software may behave in unexpected way.

 *****************************************************************************/

/**
 *  \file     Can_Cfg.h
 *
 *  \brief    This file contains generated pre compile configuration file for
 *            CAN MCAL driver
 *
 */

/**
 *
 ******************************************************************************
 * \defgroup MCAL_CAN_CFG Can Configuration
 *
 * This files defines CAN MCAL configuration structures
 *  @{
 ******************************************************************************/

#ifndef CAN_CFG_H_
#define CAN_CFG_H_

#include "Dem.h"
#include "Os.h"
#ifdef __cplusplus
extern "C" {
#endif

/** \brief CAN Config ID */
#define CAN_CFG_ID          (CAN_CFG_ID_0)

/**
*  \brief CAN Build Variant.
*   Build variants.(i.e Pre Compile,Post Build)
*/

#define CAN_VARIANT_POST_BUILD	(STD_ON)

/**
 *  \name Can Driver Configuration SW Version Info
 *
 *  Defines for CAN Driver configuration version
 *  @{
 */
/** \brief Can configuration Major Version */
#define CAN_CFG_MAJOR_VERSION           (9U)
/** \brief Can configuration Minor Version */
#define CAN_CFG_MINOR_VERSION           (0U)
/** \brief Can configuration Patch Version */
#define CAN_CFG_PATCH_VERSION           (1U)
/* @} */


/**
 *  \name Can Driver Configuration SW Version Info
 *
 *  Pre-compile switches for enabling/disabling CAN MCAL APIs
 *  @{
 */
#define CAN_VERSION_INFO_API   (STD_ON)
/*!< Enable/Disable Can_GetVersionInfo() */

#define CAN_DEV_ERROR_DETECT  (STD_ON)
/*!< Enable/Disable DEV error detection */
#define CAN_DEINIT_API  (STD_ON)
/*!< Enable/Disable Can_DeInit() API */
#define CAN_SET_BAUDRATE_API  (STD_OFF)
/*!< Enable/Disable Can_SetBaudrate() API */
#define CAN_LOOPBACK_ENABLE   (STD_ON)
/*!< Enable/Disable Can_TestLoopBackModeEnable() */
#define CAN_WAKEUP_FUNCTIONALITY_API        (STD_OFF)
/*!< Enable/Disable Can_CheckWakeup() */
#define CAN_MULTIPLEXED_TRANSMISSION_ENABLE (STD_OFF)
/*!< Enable/Disable Multiplexed Transmission */
#define CAN_TRIGGER_TRANSMIT_ENABLE (STD_OFF)
/*!< Enable/Disable CanIf_TriggerTransmit */

/**
*  \brief CAN Build Variant.
*   Build Variants.(i.e Pre-compile,Post-Build or Link time)
*/

 /*mixed mode is allowed */

#define CAN_TX_POLLING      (STD_OFF)
/*!< Enable/Disable Can_MainFunction_Write */
#define CAN_RX_POLLING      (STD_OFF)
/*!< Enable/Disable Can_MainFunction_Read */
#define CAN_BUSOFF_POLLING  (STD_OFF)
/*!< Enable/Disable Can_MainFunction_BusOff */
#define CAN_WAKEUP_POLLING  (STD_OFF)
/*!< Enable/Disable Can_MainFunction_Wakeup */
#define CAN_ECC_ENABLE      STD_OFF
/*!< Enable/Disable single bit ECC logic */
/* @} */

/*!< Maximum number of Config sets */
/*!< Max Baud rate config structs */
#define CAN_NUM_CONTROLLER          (1U)
/*!< Max number of controllers defined*/

#define CAN_NUM_MAILBOXES           (8U)
/*!< Max number of mailboxes defined*/
#define CAN_MAX_CONTROLLER          (4U)
/*!< Max number of mailboxes per controller */

#define CAN_NUM_TX_MAILBOXES 		(4U)
/*!< Total Number of TX mailboxes */

#define CAN_ISR_TYPE                (CAN_ISR_CAT2)
/*!< Enable/Disable OSEK Category 1 ISR */

/**
 *  \name Can Controller Id names
 *
 *  Defines for symbolic names for the CanControllerIds
 *  @{
 */
#define CanConf_CanController_EcuTestNode   (0U)
/* @} */

/* @} */

#define CAN_CONTROLLER_MCAN1

/**
 *  \name Can HW Object names
 *
 *  Defines for symbolic names for the CanHardwareObjectIds
 *  @{
 */

#define CanConf_CanHardwareObject_HOH_0_EcuTestNode   (0U)
#define CAN_HTRH_0         (CanConf_CanHardwareObject_HOH_0_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_1_EcuTestNode   (1U)
#define CAN_HTRH_1         (CanConf_CanHardwareObject_HOH_1_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_2_EcuTestNode   (2U)
#define CAN_HTRH_2         (CanConf_CanHardwareObject_HOH_2_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_3_EcuTestNode   (3U)
#define CAN_HTRH_3         (CanConf_CanHardwareObject_HOH_3_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_4_EcuTestNode   (4U)
#define CAN_HTRH_4         (CanConf_CanHardwareObject_HOH_4_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_5_EcuTestNode   (5U)
#define CAN_HTRH_5         (CanConf_CanHardwareObject_HOH_5_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_6_EcuTestNode   (6U)
#define CAN_HTRH_6         (CanConf_CanHardwareObject_HOH_6_EcuTestNode)

#define CanConf_CanHardwareObject_HOH_7_EcuTestNode   (7U)
#define CAN_HTRH_7         (CanConf_CanHardwareObject_HOH_7_EcuTestNode)

/* @} */

/* @} */

/** \brief Counter ID for counter used to count wait ticks */
#define CAN_OS_COUNTER_ID               ((CounterType)HwCounter)

/**
*  \brief CAN timeout - used in CAN IFCMD busy wait and Start/Stop busy wait.
*   Specifies the maximum time for blocking function until a timeout is detected.
*   Unit is milli seconds.
*/
#define CAN_TIMEOUT_DURATION            (10000U)



/* DEM Error Definitions */
/* DEM Error Codes */
/** \brief No event error code */
#define DemConf_DemEventParameter_CAN_DEM_NO_EVENT (0xFFFFU)
#define CAN_DEM_NO_EVENT DemConf_DemEventParameter_CAN_DEM_NO_EVENT

#ifndef CAN_E_HARDWARE_ERROR
/** \brief Hardware failed */
#define CAN_E_HARDWARE_ERROR          (DemConf_DemEventParameter_CAN_E_HARDWARE_ERROR)
#endif

/* ========================================================================== */
/*                         Structures and Enums                               */
/* ========================================================================== */

/**
 * \brief Can Mailbox direction enum
 */
typedef enum
{
    CAN_CONTROLLER_INSTANCE_MCAN0 = 0x0U,
    /**< MCAN0 Controller Instance */
    CAN_CONTROLLER_INSTANCE_MCAN1 = 0x1U,
    /**< MCAN1 Controller Instance */
    CAN_CONTROLLER_INSTANCE_MCAN2 = 0x2U,
    /**< MCAN2 Controller Instance */
    CAN_CONTROLLER_INSTANCE_MCAN3 = 0x3U
    /**< MCAN3 Controller Instance */
} Can_ControllerInstance;


/** \brief CAN Configuration struct declaration */
extern const struct Can_ConfigType_s CanConfigSet;

extern const struct Can_ControllerStruct_PC CanConfigSet_PC_EcuTestNode;


/** \brief CAN Controller Pre Compile Configuration List */
extern const struct Can_ControllerStruct_PC
    *CanConfigSet_CanController_List_PC[CAN_NUM_CONTROLLER];

/** \brief CAN Mailbox Pre Compile Configuration List */
extern const struct Can_MailboxStruct_PC
    *CanConfigSet_CanHardwareObject_List_PC[CAN_NUM_MAILBOXES];


#ifdef __cplusplus
}
#endif

#endif /*CAN_CFG_H__*/

/* @} */
/**********************************************************************************************************************
 *  END OF FILE: Can_Cfg.h
 *********************************************************************************************************************/
