/**
 * \file
 *
 * \brief AUTOSAR MemMap
 *
 * This file contains the implementation of the AUTOSAR
 * module MemMap.
 *
 * \version 1.3.14
 *
 * \author Elektrobit Automotive GmbH, 91058 Erlangen, Germany
 *
 * Copyright 2005 - 2023 Elektrobit Automotive GmbH
 * All rights exclusively reserved for Elektrobit Automotive GmbH,
 * unless expressly agreed to otherwise.
 */

/*==================[inclusions]=============================================*/

#define MEMMAP_ERROR_CAN

/*------------------[Start of a module]--------------------------------------*/

/* Memory section macros for Can */

#if (defined CAN_START_SEC_CODE)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_CODE within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_CODE
    #undef CAN_START_SEC_CODE
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_CODE)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_CODE)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_CODE
    #undef CAN_STOP_SEC_CODE
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_CODE without prior opening CAN_START_SEC_CODE.
  #endif

#elif (defined CAN_START_SEC_CONFIG_DATA)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_CONFIG_DATA within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_CONFIG_DATA
    #undef CAN_START_SEC_CONFIG_DATA
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_CONFIG_DATA)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_CONFIG_DATA)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_CONFIG_DATA
    #undef CAN_STOP_SEC_CONFIG_DATA
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_CONFIG_DATA without prior opening CAN_START_SEC_CONFIG_DATA.
  #endif

#elif (defined CAN_START_CONFIG_DATA)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_CONFIG_DATA within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTCONFIG_DATA
    #undef CAN_START_CONFIG_DATA
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_CONFIG_DATA)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTCONFIG_DATA)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTCONFIG_DATA
    #undef CAN_STOP_CONFIG_DATA
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_CONFIG_DATA without prior opening CAN_START_CONFIG_DATA.
  #endif

#elif (defined CAN_START_SEC_CONST_UNSPECIFIED)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_CONST_UNSPECIFIED within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_CONST_UNSPECIFIED
    #undef CAN_START_SEC_CONST_UNSPECIFIED
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_CONST_UNSPECIFIED)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_CONST_UNSPECIFIED)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_CONST_UNSPECIFIED
    #undef CAN_STOP_SEC_CONST_UNSPECIFIED
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_CONST_UNSPECIFIED without prior opening CAN_START_SEC_CONST_UNSPECIFIED.
  #endif

#elif (defined CAN_START_SEC_ISR_CODE)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_ISR_CODE within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_ISR_CODE
    #undef CAN_START_SEC_ISR_CODE
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_ISR_CODE)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_ISR_CODE)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_ISR_CODE
    #undef CAN_STOP_SEC_ISR_CODE
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_ISR_CODE without prior opening CAN_START_SEC_ISR_CODE.
  #endif

#elif (defined CAN_START_SEC_VAR_INIT_16)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_INIT_16 within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_16
    #undef CAN_START_SEC_VAR_INIT_16
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_INIT_16)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_16)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_16
    #undef CAN_STOP_SEC_VAR_INIT_16
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_INIT_16 without prior opening CAN_START_SEC_VAR_INIT_16.
  #endif

#elif (defined CAN_START_SEC_VAR_INIT_32)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_INIT_32 within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_32
    #undef CAN_START_SEC_VAR_INIT_32
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_INIT_32)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_32)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_32
    #undef CAN_STOP_SEC_VAR_INIT_32
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_INIT_32 without prior opening CAN_START_SEC_VAR_INIT_32.
  #endif

#elif (defined CAN_START_SEC_VAR_INIT_8)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_INIT_8 within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_8
    #undef CAN_START_SEC_VAR_INIT_8
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_INIT_8)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_8)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_8
    #undef CAN_STOP_SEC_VAR_INIT_8
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_INIT_8 without prior opening CAN_START_SEC_VAR_INIT_8.
  #endif

#elif (defined CAN_START_SEC_VAR_INIT_UNSPECIFIED)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_INIT_UNSPECIFIED within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_UNSPECIFIED
    #undef CAN_START_SEC_VAR_INIT_UNSPECIFIED
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_INIT_UNSPECIFIED)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_UNSPECIFIED)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_INIT_UNSPECIFIED
    #undef CAN_STOP_SEC_VAR_INIT_UNSPECIFIED
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_INIT_UNSPECIFIED without prior opening CAN_START_SEC_VAR_INIT_UNSPECIFIED.
  #endif

#elif (defined CAN_START_SEC_VAR_NO_INIT_16)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_NO_INIT_16 within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_16
    #undef CAN_START_SEC_VAR_NO_INIT_16
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_NO_INIT_16)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_16)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_16
    #undef CAN_STOP_SEC_VAR_NO_INIT_16
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_NO_INIT_16 without prior opening CAN_START_SEC_VAR_NO_INIT_16.
  #endif

#elif (defined CAN_START_SEC_VAR_NO_INIT_32)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_NO_INIT_32 within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_32
    #undef CAN_START_SEC_VAR_NO_INIT_32
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_NO_INIT_32)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_32)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_32
    #undef CAN_STOP_SEC_VAR_NO_INIT_32
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_NO_INIT_32 without prior opening CAN_START_SEC_VAR_NO_INIT_32.
  #endif

#elif (defined CAN_START_SEC_VAR_NO_INIT_8)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_NO_INIT_8 within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_8
    #undef CAN_START_SEC_VAR_NO_INIT_8
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_NO_INIT_8)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_8)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_8
    #undef CAN_STOP_SEC_VAR_NO_INIT_8
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_NO_INIT_8 without prior opening CAN_START_SEC_VAR_NO_INIT_8.
  #endif

#elif (defined CAN_START_SEC_VAR_NO_INIT_UNSPECIFIED)
  #ifdef MEMMAP_SECTION_OPENED
    #undef MEMMAP_ERROR_CAN
    #error Tried to open section CAN_START_SEC_VAR_NO_INIT_UNSPECIFIED within an already open section.
  #else
    #define MEMMAP_SECTION_OPENED
    #define MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_UNSPECIFIED
    #undef CAN_START_SEC_VAR_NO_INIT_UNSPECIFIED
    #undef MEMMAP_ERROR_CAN
  #endif
#elif (defined CAN_STOP_SEC_VAR_NO_INIT_UNSPECIFIED)
  #if (defined MEMMAP_SECTION_OPENED) && (defined MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_UNSPECIFIED)
    #undef MEMMAP_SECTION_OPENED
    #undef MEMMAP_SECTION_OPENED_STARTSEC_VAR_NO_INIT_UNSPECIFIED
    #undef CAN_STOP_SEC_VAR_NO_INIT_UNSPECIFIED
    #undef MEMMAP_ERROR_CAN
  #else
    #undef MEMMAP_ERROR_CAN
    #error Tried to close section CAN_STOP_SEC_VAR_NO_INIT_UNSPECIFIED without prior opening CAN_START_SEC_VAR_NO_INIT_UNSPECIFIED.
  #endif

#endif

#if ((!defined MEMMAP_ERROR_CAN) && (defined MEMMAP_ERROR))
  #undef MEMMAP_ERROR
#elif ((defined MEMMAP_ERROR_CAN) && (!defined MEMMAP_ERROR))
  #undef MEMMAP_ERROR_CAN
  #error MEMMAP_ERROR_CAN the included memory section was not defined within the BSW-IMPLEMENTATION of Can.
#endif
